==========================
The ``lino-amici`` package
==========================




**Lino Amici** is a Lino Django application for managing family contacts.

- Source code: https://gitlab.com/lino-framework/amici

- This is an integral part of the Lino framework, which is documented
  at https://www.lino-framework.org

- The changelog is at https://www.lino-framework.org/changes

- For introductions, commercial information and hosting solutions
  see https://www.saffre-rumma.net

- This is a sustainably free open-source project. Your contributions are
  welcome.  See https://community.lino-framework.org for details.



